import { visit } from "unist-util-visit";
export default function rehypeFilter(options) {
  if (options.allowedElements && options.disallowedElements) {
    throw new TypeError(
      "Only one of `allowedElements` and `disallowedElements` should be defined"
    );
  }
  if (options.allowedElements || options.disallowedElements || options.allowElement) {
    return (tree) => {
      visit(tree, "element", (node, index, parent) => {
        let remove;
        if (options.allowedElements) {
          remove = !options.allowedElements.includes(
            node.tagName
          );
        } else if (options.disallowedElements) {
          remove = options.disallowedElements.includes(
            node.tagName
          );
        }
        if (!remove && options.allowElement && typeof index === "number" && parent) {
          remove = !options.allowElement(
            node,
            index,
            parent
          );
        }
        if (remove && typeof index === "number" && parent) {
          if (options.unwrapDisallowed && node.children) {
            parent.children.splice(
              index,
              1,
              ...node.children
            );
          } else {
            parent.children.splice(index, 1);
          }
          return index;
        }
        return void 0;
      });
    };
  }
}
